@@ -173,6 +173,8 @@ class JsonList(list):
 
     def _typeCheck(self, val):
         if self.list_type:
+            if self.list_type is float and type(val) is int: #json ints can also be floats
+                val = float(val)
             check_type(val, self.list_type, "Wrong type %s, this list can hold only instances of %s" % (type(val), str(self.list_type)))
         else:
             if not (issubclass(type(val), JsonObject) or isinstance(val, (str, int, float, bool, JsonList))):
@@ -266,3 +268,24 @@ class JsonList(list):
             else:
                 new_list.append(i)
         return new_list
+
+    def save(self, file_path: str):
+        with open(file_path, 'w') as f:
+            f.write(str(self))
+
+    @classmethod
+    def load_from_file(cls, file_path: str):
+        if not path.exists(file_path):
+            return None
+        json_content = ""
+        with open(file_path) as f:
+            json_content = f.read()
+        if cls is JsonList:
+            return cls.parse(json_content)
+
+    @classmethod
+    def load_from_url(cls, uri: str):
+        req = requests.get(uri)
+        if req.status_code == 200:
+            return cls.parse(req.text)
+        return None
